@@ -2,7 +2,10 @@
 #
 # Tests for tokens of wrong type
 
-import lex
+import sys
+sys.path.insert(0,"..")
+
+import ply.lex as lex
 
 tokens = "PLUS MINUS NUMBER"
 
@@ -13,7 +16,6 @@ t_NUMBER = r'\d+'
 def t_error(t):
     pass
 
-import sys
 sys.tracebacklimit = 0
 
 lex.lex()
