@@ -2,7 +2,10 @@
 #
 # Bad token name
 
-import lex
+import sys
+sys.path.insert(0,"..")
+
+import ply.lex as lex
 
 tokens = [
     "PLUS",
@@ -18,7 +21,6 @@ t_NUMBER = r'\d+'
 def t_error(t):
     pass
 
-import sys
 sys.tracebacklimit = 0
 
 lex.lex()
