@@ -6,6 +6,9 @@
 import sys
 sys.tracebacklimit = 0
 
+sys.path.insert(0,"..")
+import ply.yacc as yacc
+
 from calclex import tokens
 
 # Parsing rules
@@ -55,7 +58,6 @@ def p_expression_name(t):
 def p_error(t):
     print "Syntax error at '%s'" % t.value
 
-import yacc
 yacc.yacc()
 
 
